task batch {
    String sample_id
    Array[File] tumor_bam
    Array[File] tumor_bai
    Array[File] normal_bam
    Array[File] normal_bai
    File bed
    File faidx
    File fasta
    File? ref_flat
    File access_bed
    File? reference
    String method
    String docker
    String cluster_config
    String disk_size

    String command = if defined(ref_flat) && !defined(reference) then "--annotate ${ref_flat}" \
    elif !defined(ref_flat) && defined(reference) then "--reference ${reference}" \
    else "--annotate ${ref_flat} --reference ${reference}"

    command <<<
        set -o pipefail
        set -e
        mkdir -p /cromwell_root/tmp/cnvkit
        cp ${sep=' ' normal_bai} /cromwell_root/tmp/cnvkit
        cp ${sep=' ' tumor_bai} /cromwell_root/tmp/cnvkit
        cp ${fasta} /cromwell_root/tmp/cnvkit/hg38.fa
        cp ${faidx} /cromwell_root/tmp/cnvkit/hg38.fai
        cd /cromwell_root/tmp/cnvkit
        
        mkdir results
        cnvkit.py batch ${sep=' ' tumor_bam} --normal ${sep=' ' normal_bam} \
        --targets ${bed} --method ${method} \
        ${command} \
        --fasta hg38.fa --access ${access_bed} \
        --output-reference ~/${sample_id}.reference.cnn \
        --output-dir ./results/ \
        --drop-low-coverage --diagram --scatter
    >>>

    runtime { 
        docker: docker
        cluster: cluster_config
        systemDisk: "cloud_ssd 40"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
    }

    output {
        File reference_cnn = "${sample_id}.reference.cnn"
        Array[File] results = glob("/cromwell_root/tmp/cnvkit/results/*")
    }
}